@@ -6,7 +6,7 @@ Catmandu::Exporter::BagIt - Package that exports data as BagIts
 
 =head1 SYNOPSIS
 
-   use Catmandu::Exporter::BagIt
+   use Catmandu::Exporter::BagIt;
 
    my $exporter = Catmandu::Exporter::BagIt->new(
                             overwrite     => 0 ,
@@ -95,7 +95,7 @@ use IO::File;
 use LWP::Simple;
 use Moo;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 with 'Catmandu::Exporter';
 
@@ -111,7 +111,7 @@ sub add {
 
     return 1 if -d $directory && $self->ignore_existing;
 
-	  Catmandu::Error->throw("$directory exists") if -d $directory && ! $self->overwrite;
+    Catmandu::Error->throw("$directory exists") if -d $directory && ! $self->overwrite;
 
     my $bagit = defined($self->user_agent) ? 
                     Catmandu::BagIt->new(user_agent => $self->user_agent) : 
@@ -130,7 +130,7 @@ sub add {
 
             mkpath("$directory/data") unless -d "$directory/data";
 
-            my ($fh, $filename) = tempfile();
+            my ($fh, $filename) = tempfile(UNLINK => 1);
 
             # For now using a simplistic mirror operation
             my $response = $bagit->_http_client->mirror($url,$filename);
@@ -150,4 +150,4 @@ sub add {
 
 sub commit { 1 }
 
-1;
\ No newline at end of file
+1;
